# Security Policy

## Supported Versions

| Version | Supported          |
|---------|--------------------|
| 3.x     | :white_check_mark: |
| < 3.0   | :x:                |

## Reporting a Vulnerability

We take security vulnerabilities in our open-source project seriously and appreciate responsible disclosure from users.

If you believe you have found a security vulnerability in our project, please report it to us by creating a Github issue with the label "security" or "vulnerability". Please do not publicly disclose the vulnerability until it has been addressed by our project team.

We will acknowledge receipt of your vulnerability report and will keep you informed of our progress in addressing the vulnerability. If you would like to communicate with us about the vulnerability, please email [imonenext at gmail dot com].

We will not take legal action against users who report vulnerabilities in good faith and in accordance with this disclosure policy.

Thank you for helping us keep our open-source project secure!
